This crate provides two search functions search and search_case_insensitive
to query a string from another multi-line string.
This crate provides two search functions search and search_case_insensitive
to query a string from another multi-line string.